#
# spec file for package sca-patterns-base
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define sca_common sca
%define patdirbase %{_prefix}/lib/%{sca_common}
%define patdir %{patdirbase}/patterns
%define patuser root
%define patgrp root

Name:           sca-patterns-base
Version:        1.6.0
Release:        2.3
Summary:        Supportconfig Analysis Pattern Base Libraries
License:        GPL-2.0-only
URL:            https://github.com/g23guy/sca-patterns-base
Group:          System/Monitoring
Source:         %{name}-%{version}.tar.gz
Requires:       bash
Requires:       perl
Requires:       python3-base
Provides:       sca-patterns-template-gen2
BuildArch:      noarch

%description
Supportconfig Analysis (SCA) appliance pattern base libraries used
by all patterns

%prep
%setup -q

%build

%install
pwd;ls -la
install -d %{buildroot}/%{patdirbase}/patterns/local
install -d %{buildroot}/%{patdirbase}/bash
install -d %{buildroot}/%{patdirbase}/python
install -d %{buildroot}/%{patdirbase}/perl/SDP
install -d %{buildroot}%{_docdir}/%{name}
install -m 444 libraries/COPYING.GPLv2 %{buildroot}%{_docdir}/%{name}
install -m 644 libraries/bash/* %{buildroot}/%{patdirbase}/bash
install -m 644 libraries/python/* %{buildroot}/%{patdirbase}/python
install -m 644 libraries/perl/SDP/* %{buildroot}/%{patdirbase}/perl/SDP

%files
%defattr(-,%{patuser},%{patgrp})
%dir %{patdirbase}
%dir %{patdir}
%dir %{patdir}/local
%dir %{patdirbase}/bash
%dir %{patdirbase}/python
%dir %{patdirbase}/perl
%dir %{patdirbase}/perl/SDP
%dir %attr(-,root,root) %{_docdir}/%{name}
%attr(-,%{patuser},%{patgrp}) %{patdirbase}/bash/*
%attr(-,%{patuser},%{patgrp}) %{patdirbase}/python/*
%attr(-,%{patuser},%{patgrp}) %{patdirbase}/perl/SDP/*
%doc %attr(-,root,root) %{_docdir}/%{name}/*

%changelog
* Tue Jan  9 2024 jason.record@suse.com
- Minor spec file formatting changes.
* Wed Nov 29 2023 jason.record@suse.com
- Changes in version 1.6.0
  + Updates for ALP using new classes and modules (bsc#1217674)
* Thu Aug 31 2023 jason.record@suse.com
- Changes to version 1.5.2
  + Fixed SUSE.getRpmInfo to find the correct rpm.txt section (bsc#1210908)
  + Changes to python/SUSE.py version 1.0.1
  - Changed name from getScInfo to getSCInfo
  - Fixed getSCInfo error on basic-environment.txt (bsc#1205826)
  - Updated SLES version constants
* Wed Oct 26 2022 jason.record@suse.com
- Changes to version 1.5.1
  + Fixed UnicodeDecodeError when reading files (bsc#1204723)
* Thu Nov  4 2021 Jason Record <jason.record@suse.com>
- Changes to updated version 1.5.0
  + Converted to python3 (bsc#1191005, SLE-21579)
* Mon Oct  4 2021 Jason Record <jason.record@suse.com>
- Changed Requires python to python-base (bsc#1191199)
* Mon Aug 16 2021 Jason Record <jason.record@suse.com>
- Updated kernel version constants for all SUSE libraries (bsc#1189483)
* Thu Jun 10 2021 Jason Record <jason.record@suse.com>
- Additions to version 1.3.3
  + Added Core.loadFullFile for sectionless parsing (bsc#1187194)
* Tue May 18 2021 Jason Record <jason.record@suse.com>
- Additions to version 1.3.2
  + Added SUSE.getNetworkInterfaces needed for bsc#1144162
  + Updated documentation for SUSE.compareKernel
- Removed Novell/OES references from libraries (bsc#1186034)
- Changed SUSE.securityAnnouncementPackageCheck in Python to warnings
  and only critical for critical announcements
* Tue May  4 2021 Jason Record <jason.record@suse.com>
- SUSE.getFileSystems fixes invalid index error (bsc#1185594)
- SUSE.getFileSystems fixes unbound local SWAP variable (bsc#1185593)
* Fri Nov  6 2020 jason.record@suse.com
- Additions to version 1.3.1
  + SUSE.getHostInfo doesn't use /etc/os-release (bsc#1178523)
  + SUSE.py missing initial kernel version constants (bsc#1178524)
* Tue Jan  2 2018 jason.record@suse.com
- Removed unnecessary %%clean from spec
* Mon Dec 18 2017 jason.record@suse.com
- Updated spec file with spec-cleaner suggestions
* Fri Jun  2 2017 jason.record@suse.com
- Updated SLES12SP2 global library value (bsc#1042515)
* Thu Jun  1 2017 jason.record@suse.com
- Added getRegExSectionRaw to Core.py
* Fri Jun  3 2016 jason.record@suse.com
- Updated Core.py documentation
* Tue Apr 26 2016 jrecord@suse.com
- Assigned correct kernel version for global SLE12SP1 (bsc#977269)
* Tue Feb 23 2016 jrecord@suse.com
- Updated patterns (bsc#953203)
* Wed Aug 26 2015 jrecord@suse.com
- Fixed oes.ncsActive to detect active cluster better
* Thu Jul 30 2015 jrecord@suse.com
- Added python library function:
  SUSE.getConfigFileLVM
- Updated constant SLE11SP4 in SUSE.pm, SUSE.rc, SUSE.py
- Added constants to all SUSE libraries
  SLE11SP5, SLE12SP1, SLE12SP2, SLE12SP3, SLE12SP4, SLE12SP5
* Fri Jun 26 2015 jrecord@suse.com
- Added python library functions:
  SUSE.getFileSystems
  SUSE.getGrub2Config
  SUSE.getBasicFIPSData
* Wed Jun 24 2015 jrecord@suse.com
- Added python library function:
  SUSE.getBasicVirtualization
  SUSE.getProcCmdLine
* Wed Jun 24 2015 jrecord@suse.com
- Added MPIO.py python library, with functions:
  MPIO.devicesManaged
  MPIO.convertKeyValue
  MPIO.getManagedDevices
  MPIO.getDiskID
  MPIO.partitionManagedDevice
- Added python library functions:
  Xen.getConfigFiles
  Xen.getDiskValueList
* Fri May  1 2015 jrecord@suse.com
- Added python library functions:
  SUSE.getZypperProductList
  SUSE.getZypperRepoList
  SUSE.getSCCInfo
  SUSE.getSCRunTime
* Fri Jan 30 2015 jrecord@suse.com
- Update Makefile for submissions
* Tue Jan 27 2015 jrecord@suse.com
- Updated python/SUSE.py docs
* Tue Jan 13 2015 jrecord@suse.com
- Updated perl docs on OESLinux.pm
* Sat Jan 10 2015 jrecord@suse.com
- Created new OES library oes.py
* Mon Dec 15 2014 jrecord@suse.com
- Added SLE11SP4 to bash SUSE library
- Added SLE12SP1 to all SUSE libraries
- SDP::SUSE::getFileSystems() now ignores lines starting with ---
* Tue Dec  2 2014 jrecord@suse.com
- Created new SUSE Manger library suma.py
* Tue Sep 23 2014 jrecord@suse.com
- Added the PatchInfo class to SUSE.py
* Tue Jul 22 2014 jrecord@suse.com
- Fixed getServiceInfo for unknown services (bnc#888241)
* Thu Jun 26 2014 jrecord@suse.com
- Fixed SUSE.getHostInfo OES patchlevel error
- Added Python SUSE.securityAnnouncementPackageCheck
- SDP::SUSE::securityAnnouncementPackageCheck error when not installed
- getSection in Core.pm excludes commented lines
* Thu Jun 19 2014 jrecord@suse.com
- getSection in Core.py excludes commented lines
- Removed unecessary python imported libraries
- Added listSections to Core.py
- Added haeEnabled to HAE.py
- Added haeConnected to HAE.Py
- Added getNodeInfo to HAE.py
- Added getConfigCTDB to HAE.py
- Added getConfigCorosync to HAE.py
- Added getClusterConfig to HAE.Py
* Fri Jun 13 2014 jrecord@suse.com
- Fixed TypeError: cannot concatenate 'str' and 'exceptions.IOError' objects
* Thu Jun 12 2014 jrecord@suse.com
- Fixed getSection to find valid sections (bnc#882507)
* Wed Jun 11 2014 jrecord@suse.com
- Updated HAE.py documentation
- Added HAE.py with getSBDInfo
- Added getHostInfo to SUSE.py
- Added getSeriveInfo to SUSE.py
* Thu May 15 2014 jrecord@suse.com
- Fixed eDirStatus() in Perl eDir.pm when ndsstat is missing
* Mon May 12 2014 jrecord@suse.com
- Fixed build errors for common directory
* Fri May  2 2014 jrecord@suse.com
- Removed debug printouts
* Mon Apr 28 2014 jrecord@suse.com
- Removed SUSE.getVersion, SUSE.normalizeVersionName and CVE.py
  No patterns currently use or plan to this library and functions
- Added Core.normalizeVersionString and Core.compareLooseVersions
- Added new Core.compareVersions that checks left significant elements
* Mon Mar 31 2014 jrecord@suse.com
- Added STATUS_IGNORE to Core.pm
* Thu Mar 20 2014 jrecord@suse.com
- Removed hash pling from libraries
* Thu Mar 13 2014 jrecord@suse.com
- Updated copyright FSF address in all libraries
- Change to System/Monitoring spec Group
* Fri Feb 21 2014 jrecord@suse.com
- Added SUSE.py python functions
  getServiceDInfo, serviceHealthD
* Wed Jan 22 2014 jrecord@suse.com
- python Core.getSection excludes commented lines
* Fri Jan 17 2014 jrecord@suse.com
- moved libraries to root of lib directory
- relocated files according to FHS
- added Xen.py library
- added pydoc elements to python libraries for documentation
- added STATUS_IGNORE to all Core libraries
* Wed Jan  8 2014 jrecord@suse.com
- fixed build errors
* Thu Jan  2 2014 jrecord@suse.com
- moved pat to sca-appliance-patdev
* Fri Dec 20 2013 jrecord@suse.com
- separated as individual RPM package
